---
title: <span class="badge object-type-scalar"></span> BoolOnOff
---
# <span class="badge object-type-scalar"></span> BoolOnOff

Boolean: On / Off

## Definition

```python
# Boolean: On / Off
BoolOnOff: typing.Literal["bool_on_off"] = "bool_on_off"
```
